@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = sprintf "%d.%03d", q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 2.2 $ =~ /(\d+)\.(\d+)/;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -22,46 +22,46 @@ sub print
     my $popup = $cw -> Toplevel ;
     $popup -> title ($cw->{'title'}.' print query') ;
     $popup -> grab ;
-    $popup -> Label(text => 'modify print command as needed :') -> pack ;
-    my $pentry = $popup -> Entry(textvariable => $cw->{_printCmdRef}) 
-      -> pack(fill => 'x') ;
-    $popup -> Label(text => 'print on file :') -> pack ;
-    my $fentry = $popup -> Entry(textvariable => \$cw->{_printFile},
-                                state => 'disabled' ) ;
+    $popup -> Label(-text => 'modify print command as needed :') -> pack ;
+    my $pentry = $popup -> Entry(-textvariable => $cw->{_printCmdRef}) 
+      -> pack(-fill => 'x') ;
+    $popup -> Label(-text => 'print on file :') -> pack ;
+    my $fentry = $popup -> Entry(-textvariable => \$cw->{_printFile},
+				 -state => 'disabled' ) ;
 
     $popup -> Checkbutton
       (
        -text => 'print to file',
        -variable => \$cw->{_printToFile},
-       command => sub 
+       -command => sub 
        {
          if ($cw->{_printToFile})
            {
-             $fentry->configure(state => 'normal');
-             $pentry->configure(state => 'disabled');
+             $fentry->configure(-state => 'normal');
+             $pentry->configure(-state => 'disabled');
            }
          else
            {
-             $pentry->configure(state => 'normal');
-             $fentry->configure(state => 'disabled');
+             $pentry->configure(-state => 'normal');
+             $fentry->configure(-state => 'disabled');
            }
        }
       ) -> pack ;
 
-    $fentry -> pack(fill => 'x') ;
+    $fentry -> pack(-fill => 'x') ;
 
-    my $f = $popup -> Frame -> pack(fill => 'x') ;
-    $f -> Button (text => 'print', 
-                  command => sub {
+    my $f = $popup -> Frame -> pack(-fill => 'x') ;
+    $f -> Button (-text => 'print', 
+                  -command => sub {
                     $cw -> doPrint(); 
                     $popup -> destroy ;
                   })
-      -> pack (side => 'left') ;
-    $f -> Button (text => 'default', 
-                  command => sub {$cw->resetPrintCmd();})
-      -> pack (side => 'left') ;
-    $f -> Button (text => 'cancel', command => sub {$popup -> destroy ;})
-      -> pack (side => 'right') ;
+      -> pack (-side => 'left') ;
+    $f -> Button (-text => 'default', 
+                  -command => sub {$cw->resetPrintCmd();})
+      -> pack (-side => 'left') ;
+    $f -> Button (-text => 'cancel', -command => sub {$popup -> destroy ;})
+      -> pack (-side => 'right') ;
   }
 
 sub doPrint
@@ -92,6 +92,28 @@ sub setPrintCmd
     $$ref = shift ;
   }
 
+sub normalize
+  {
+    my ($cw) = shift;
+
+    my $href ;
+    if (@_ == 1 ) 
+      {
+	$href = shift;
+      }
+    else
+      {
+	my %h = @_ ;
+	$href = \%h ;
+      }
+
+    # add '-' to keys if necessary
+    map { $href->{'-'.$_} = delete $href->{$_} unless /^-/ } keys %$href ;
+
+    return %$href ;
+  }
+
+
 
 1;
 __END__
@@ -114,9 +136,9 @@ soon to be released PrintDialog widget.
 
 =head1 AUTHOR
 
-Dominique Dumont, Dominique_Dumont@grenoble.hp.com
+Dominique Dumont, domi@komarr.grenoble.hp.com
 
-Copyright (c) 1997-1998 Dominique Dumont. All rights reserved.
+Copyright (c) 1997-1998,2004 Dominique Dumont. All rights reserved.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
